@@ -18,7 +18,7 @@ our @EXPORT_OK = qw(
                     remove_trace
                 );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 $SIG{INT} = sub { 'this ensures END runs if ^C is pressed'; };
 
@@ -122,8 +122,7 @@ sub install_trace {
 
     my $file = $p{file};
     my $extensions = $p{extensions};
-    my $include = $p{include};
-    my $exclude = $p{exclude};
+    my $inject = $p{inject};
 
     my $des_use = Devel::Examine::Subs->new(file => $file,);
 
@@ -138,8 +137,10 @@ sub install_trace {
                                         extensions => $extensions,
                                      );
 
+    $inject = $p{inject} || _inject_code();
+
     $des->inject(
-        inject_after_sub_def => _inject_code(),
+        inject_after_sub_def => $inject,
     );
 }
 sub remove_trace {
@@ -308,6 +309,10 @@ C<extensions =E<gt> ['pl', 'pm']> - Optional: By default, we change all C<.pm>
 and C<.pl> files. Specify only the extensions you want by adding them into this
 array reference, less the dot.
 
+<inject =E<gt> ['your code here;', 'more code;']> - The lines of code supplied
+here will override the default. Note that C<remove_trace()> will not remove
+these lines, and for uninstall, you'll have to manually delete them.
+
 =head2 C<remove_trace>
 
 Automatically remove all remnants of this module from a file or files, that were
@@ -319,6 +324,34 @@ Where 'filename' can be the name of a file, a directory or a 'Module::Name'.
 
 =cut
 
+=head1 EXAMPLES
+
+One-liner to install into a live module:
+
+    sudo perl -MDevel::Trace::Subs=install_trace -e 'install_trace(file => "Data::Dumper");
+
+One-liner to test that it worked:
+
+    perl -MDevel::Trace::Subs=trace_dump -e '$ENV{DTS_TRACE}=1; dd {a=>1}; trace_dump();'
+
+One-liner to uninstall:
+
+    sudo perl -MDevel::Trace::Subs=remove_trace -e 'remove_trace(file => "Data::Dumper");
+
+Install into all C<*.pm> files in a directory structure:
+
+    use warnings;
+    use strict;
+
+    use Devel::Trace::Subs qw(install_trace);
+
+    install_trace(
+                file => '/path/to/files/',
+                extensions => ['pm'],
+             );
+
+See the files in the distributions C<examples> directory for other examples.
+
 =head1 AUTHOR
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
